@@ -1,4 +1,5 @@
-{   name      => 'TestApp',
+{
+   name      => 'TestApp',
     Component => { 'Controller::Foo' => { foo => 'bar' } },
     Model     => { 'Model::Baz' => { qux => 'xyzzy' } },
     deep      => { 'buried' => { 'key' => 'value' } },
